@@ -16,9 +16,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the German language.
+"""
+This module represents the German language.
 
-.. seealso:: http://en.wikipedia.org/wiki/German_language
+.. seealso:: :wp:`German_language`
 """
 
 
