@@ -16,9 +16,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Hebrew language.
+"""
+This module represents the Hebrew language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Hebrew_language
+.. seealso:: :wp:`Hebrew_language`
 """
 
 
@@ -29,5 +30,5 @@ class he(common.Common):
     """This class represents Hebrew."""
 
     ignoretests = {
-        'all': ["acronyms", "simplecaps", "startcaps"],
+        "all": ["acronyms", "simplecaps", "startcaps"],
     }
