@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright 2002, 2003 St James Software
 #
 # This file is part of translate.
@@ -17,68 +15,69 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Implements a case-insensitive (on keys) dictionary and order-sensitive
-dictionary
 """
-
-import six
+Implements a case-insensitive (on keys) dictionary and order-sensitive
+dictionary.
+"""
 
 
 class cidict(dict):
-
     def __init__(self, fromdict=None):
-        """constructs the cidict, optionally using another dict to do so"""
+        """Constructs the cidict, optionally using another dict to do so."""
         if fromdict is not None:
             self.update(fromdict)
 
     def __getitem__(self, key):
-        if not isinstance(key, six.string_types):
-            raise TypeError("cidict can only have str or unicode as key (got %r)" %
-                            type(key))
+        if not isinstance(key, str):
+            raise TypeError(
+                "cidict can only have str or unicode as key (got %r)" % type(key)
+            )
         for akey in self.keys():
             if akey.lower() == key.lower():
-                return dict.__getitem__(self, akey)
+                return super().__getitem__(akey)
         raise IndexError
 
     def __setitem__(self, key, value):
-        if not isinstance(key, six.string_types):
-            raise TypeError("cidict can only have str or unicode as key (got %r)" %
-                            type(key))
+        if not isinstance(key, str):
+            raise TypeError(
+                "cidict can only have str or unicode as key (got %r)" % type(key)
+            )
         for akey in self.keys():
             if akey.lower() == key.lower():
-                return dict.__setitem__(self, akey, value)
-        return dict.__setitem__(self, key, value)
+                return super().__setitem__(akey, value)
+        return super().__setitem__(key, value)
 
-    def update(self, updatedict):
-        """D.update(E) -> None.
-        Update D from E: for k in E.keys(): D[k] = E[k]
+    def update(self, updatedict) -> None:
         """
-        for key, value in six.iteritems(updatedict):
+        Update from a dictionary.
+
+        D.update(E) -> None.
+        Update D from E: for k in E.keys(): D[k] = E[k].
+        """
+        for key, value in updatedict.items():
             self[key] = value
 
     def __delitem__(self, key):
-        if not isinstance(key, six.string_types):
-            raise TypeError("cidict can only have str or unicode as key (got %r)" %
-                            type(key))
+        if not isinstance(key, str):
+            raise TypeError(
+                "cidict can only have str or unicode as key (got %r)" % type(key)
+            )
         for akey in self.keys():
             if akey.lower() == key.lower():
-                return dict.__delitem__(self, akey)
+                return super().__delitem__(akey)
         raise IndexError
 
     def __contains__(self, key):
-        if not isinstance(key, six.string_types):
-            raise TypeError("cidict can only have str or unicode as key (got %r)" %
-                            type(key))
+        if not isinstance(key, str):
+            raise TypeError(
+                "cidict can only have str or unicode as key (got %r)" % type(key)
+            )
         for akey in self.keys():
             if akey.lower() == key.lower():
                 return 1
         return 0
 
-    def has_key(self, key):
-        return self.__contains__(key)
-
     def get(self, key, default=None):
         if key in self:
             return self[key]
-        else:
-            return default
+        return default
